/*
 *  Copyright (c) by CryptoSoft GmbH 1998-2017
 *  All Rights Reserved
 *  Licensed Material - Property of CryptoSoft GmbH
 *  This software is made available solely pursuant to the
 *  terms of a license agreement which governs its use.
 *
 *  Sample source for ECB mode benchmark 
 */

#if defined(WIN16) || defined(WIN32) || defined(WIN64)
#include <windows.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include <time.h>
#include "blowfish.h"

#define BLKSZ  (8)
#define NUMBLK (1000)
#define BILLION (1000000000L)

static char *algo = "16 round Blowfish";

static unsigned long bufsize = BLKSZ * NUMBLK;
static unsigned long rounds  = BLKSZ * NUMBLK;

static BLOWFISH_KS ks;

int main(int argc, char **argv)
{
  register unsigned char *b, *buf;
  register size_t i, j;
  static struct timespec t, t1;
  float ns;

  if ((buf = (unsigned char *) malloc(bufsize)) == NULL) {
    printf("%s: Error: Cannot alloc memory !\n", argv[0]);
    return 1;
  }
  clock_gettime(CLOCK_REALTIME, &t);
  for (j = 0; j < rounds; j++)
  for (b=buf, i = bufsize; i > 0; i -= BLKSZ , b += BLKSZ) blowfish_ecbencode(b,b,&ks);
  clock_gettime(CLOCK_REALTIME,&t1);
  ns = ((t1.tv_sec * BILLION + t1.tv_nsec) - (t.tv_sec * BILLION + t.tv_nsec));
  printf("Throughput %lu bytes/s for %s (ECB mode)\n", ((long)((rounds*bufsize)/(ns/BILLION))), algo);
  free(buf);
  return 0;
}

